@@ -8,6 +8,13 @@
 #include <QDBusMessage>
 #include <QObject>
 
+enum class PackageType {
+    Linglong,   // 玲珑包
+    Flatpak,    // Flatpak包  
+    Deb,        // deb包/PackageKit包
+    DCM         // DCM兼容模式包
+};
+
 class Launcher1Adaptor;
 class Launcher1Compat : public QObject, protected QDBusContext
 {
@@ -40,5 +47,6 @@ private:
     // TODO: vvv This is bad, refactor this later vvv
     QString m_packageDisplayName;
     QString m_desktopFilePath;
+    QString m_base64Icon;
     // TODO: ^^^ -------------------------------- ^^^
 };
